@@ -356,7 +356,7 @@ setup_condition_monitor (GsmAutostartApp *app)
 
                 gconf_client_add_dir (client,
                                       dir,
-                                      GCONF_CLIENT_PRELOAD_RECURSIVE, NULL);
+                                      GCONF_CLIENT_PRELOAD_NONE, NULL);
                 g_free (dir);
 
                 app->priv->condition_notify_id = gconf_client_notify_add (client,
@@ -419,7 +419,14 @@ load_desktop_file (GsmAutostartApp *app)
         /* this must only be done on first load */
         switch (app->priv->launch_type) {
         case AUTOSTART_LAUNCH_SPAWN:
-                startup_id = gsm_util_generate_startup_id ();
+                startup_id =
+                        egg_desktop_file_get_string (app->priv->desktop_file,
+                                                     "X-GNOME-Autostart-startup-id",
+                                                     NULL);
+
+                if (startup_id == NULL) {
+                        startup_id = gsm_util_generate_startup_id ();
+                }
                 break;
         case AUTOSTART_LAUNCH_ACTIVATE:
                 startup_id = g_strdup (dbus_name);
@@ -784,8 +791,8 @@ autostart_app_start_spawn (GsmAutostartApp *app,
                                                NULL,
                                                &local_error);
         if (command == NULL) {
-                g_warning ("Unable to parse command '%s': %s",
-                           command,
+                g_warning ("Unable to parse command from  '%s': %s",
+                           egg_desktop_file_get_source (app->priv->desktop_file),
                            local_error->message);
                 g_error_free (local_error);
         }
